﻿using System;
using System.Drawing;
using System.Windows.Forms;

//====================================================
// Описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================

namespace linesk
{
    // Класс модального окна настроек приложения.
    public partial class FormGameSetting : Form
    {
        /// <summary>
        /// Собственный конструктор
        /// </summary>
        /// <param name="parent">получим управление родительского окна</param>
        public FormGameSetting(Control parent)
        {
            InitializeComponent();
            formParent = parent;
        }

        readonly private Control formParent = null;


        private void FormGameSetting_Load(object sender, EventArgs e)
        {
            InitGraphItem(ref GraphItemColor1, labelGraphItemColor1);
            InitGraphItem(ref GraphItemColor2, labelGraphItemColor2);
            InitGraphItem(ref GraphItemColor3, labelGraphItemColor3);

            GraphItemColor1.Color = ColorGraphItems[0];
            GraphItemColor2.Color = ColorGraphItems[1];
            GraphItemColor3.Color = ColorGraphItems[2];

            switch (CurrentGraphItemType)
            {
                case GraphItem.TypeGraphItem.Ellipse:
                    radioButtonEllipse.Checked = true;
                    break;
                case GraphItem.TypeGraphItem.Rectangle:
                    radioButtonRectangle.Checked = true;
                    break;
                case GraphItem.TypeGraphItem.Rhombus:
                    radioButtonRhombus.Checked = true;
                    break;
            }
        }

        public Color[] ColorGraphItems = new Color[Global.AmountColorGraphItms];

        GraphItem GraphItemColor1 = null;
        GraphItem GraphItemColor2 = null;
        GraphItem GraphItemColor3 = null;
        public GraphItem.TypeGraphItem CurrentGraphItemType;

        void InitGraphItem(ref GraphItem ball, Control parent)
        {
            ball = new GraphItem(parent);
            GraphItem.CurrentTypeGraphItem = CurrentGraphItemType;
            ball.Visible = true;
            ball.Color = Color.Red;
            ball.Active = true;
            ball.CellCoordinate = new Rectangle(-1, -1, parent.Width, parent.Height);
        }

        /// <summary>
        /// Для наглядности выбора цвета геометрической фигуры,
        /// рисуем действующие модели фигур, 
        /// рисуем в оконных элементах Label,
        /// используя один обработчик события для всех Label,
        /// отличаем по свойству Tag.
        /// </summary>
        private void LabelBallColor_Paint(object sender, PaintEventArgs e)
        {
            Graphics g = e.Graphics;

            Label label = (Label)sender;
            // В дизайнерском режиме свойству Tag можно присваивать только строковые значения,
            // в режиме времени выполнения этому свойству можно присвоить любой объект.(пока)
            string tag = (string)label.Tag; 
            switch (tag)
            {
                case "1":
                    GraphItemColor1.Draw(g);
                    break;
                case "2":
                    GraphItemColor2.Draw(g);
                    break;
                case "3":
                    GraphItemColor3.Draw(g);
                    break;
            }

        }

        /// <summary>
        /// Выбор цвета для геометрических фигур.
        /// Выбор кнопки для соответствующей геометрической фигуры 
        /// осуществляется с помощью свойства tag.
        /// </summary>
        private void buttonsColors_Click(object sender, EventArgs e)
        {
            ColorDialog colorDlg = new ColorDialog();

            if (colorDlg.ShowDialog() == DialogResult.OK)
            {
                Button button = (Button)sender;
                // В дизайнерском режиме свойству Tag можно присваивать только строковые значения,
                // в режиме времени выполнения этому свойству можно присвоить любой объект.(пока)
                string tag = (string)button.Tag;
                switch (tag)
                {
                    case "1":
                        ColorGraphItems[0] = colorDlg.Color;
                        break;
                    case "2":
                        ColorGraphItems[1] = colorDlg.Color;
                        break;
                    case "3":
                        ColorGraphItems[2] = colorDlg.Color;
                        break;
                }

                GraphItemColor1.Color = ColorGraphItems[0];
                GraphItemColor2.Color = ColorGraphItems[1];
                GraphItemColor3.Color = ColorGraphItems[2];
            }
        }

        /// <summary>
        /// Выбор вида геометрической фигуры.
        /// </summary>
        private void radioButtonsGraphTypeItem_CheckedChanged(object sender, EventArgs e)
        {
            RadioButton rb = (RadioButton)sender;
            if (rb.Checked == true)
            {
                if (rb.Equals(radioButtonEllipse) == true)
                {
                    GraphItem.CurrentTypeGraphItem = GraphItem.TypeGraphItem.Ellipse;
                }
                else if (rb.Equals(radioButtonRectangle) == true)
                {
                    GraphItem.CurrentTypeGraphItem = GraphItem.TypeGraphItem.Rectangle;
                }
                else
                {
                    GraphItem.CurrentTypeGraphItem = GraphItem.TypeGraphItem.Rhombus;
                }

                formParent.Invalidate();
            }

        }

        
        /// <summary>
        /// Если пользователь выбрал тип графэлемента,
        /// закрепим выбор нажатием кнопки ОК и обновим главное окно.
        /// </summary>
        private void buttonOK_Click(object sender, EventArgs e)
        {
            CurrentGraphItemType = GraphItem.CurrentTypeGraphItem;
            formParent.Invalidate();
        }

        /// <summary>
        /// Если выбор отменен, возращаем предыдущие настройки.
        /// Благодаря статической переменной GraphItem.CurrentTypeGraphItem
        /// мы легко возвращаем прежний вид геометрической фигуры.
        /// </summary>
        private void buttonCancel_Click(object sender, EventArgs e)
        {
            GraphItem.CurrentTypeGraphItem = CurrentGraphItemType;
            formParent.Invalidate();
        }

        private void FormGameSetting_FormClosed(object sender, FormClosedEventArgs e)
        {
            // Если окно просто закрыли, приравниваем это
            // к отмене выбранных настроек.
            buttonCancel_Click(null, null);
        }

       
    }
}
